@@ -91,7 +91,7 @@ def dump_to_server(access_token, msg_queue, name, server, insecure, staging_queu
         message = msg_queue.get()
         staging_queue.put(message)
         try:
-            if send_to_server(access_token, message, name, server, insecure) == None:
+            if send_to_server(access_token, message, name, server, insecure) != None:
                 staging_queue.get() #throw away successful message
         except error.URLError as ex:
             pass
@@ -146,7 +146,7 @@ def parse_input():
                         help="toggle interactive mode")
     parser.add_argument('-l', '--lock', type=str,
                         help="partial path to directory to lock")
-    parser.add_argument('-f', '--force', action='store_true',
+    parser.add_argument('--submit', action='store_true',
                         help="wait for server response without timeout")
     parser.add_argument('-a', '--authenticate', action='store_true',
                         help="authenticate, ignoring previous authentication")
@@ -248,7 +248,7 @@ def main():
             while timer_thread.is_alive():
                 pass
 
-            if not args.force:
+            if not args.submit:
                 server_thread.terminate()
             else:
                 server_thread.join()
